from django.test import TestCase as BaseTestCase
from django.test.client import Client as BaseClient, RequestFactory
from django.contrib.auth.models import User

from post.models import Post


class TestCase(BaseTestCase):

    @classmethod
    def setUpClass(cls):
        cls.request = RequestFactory()
        cls.client = BaseClient()

        # Editor
        cls.editor, dc = User.objects.get_or_create(
            username='editor',
            email='editor@test.com'
        )
        cls.editor.set_password("password")
        cls.editor.save()

        # Post
        obj, dc = Post.objects.get_or_create(
            title='Post',
            content='aaaa <div style="page-break-after: always;"></div>bbb',
            owner=cls.editor, state='published',
        )
        obj.sites = [1]
        obj.save()
        cls.post = obj

    def test_pagination(self):
        response = self.client.get(self.post.get_absolute_url())
        self.failUnless('<a href="?page=2#jmbo-post"' in response.content)



from django.conf.urls.defaults import patterns, url

from jmbo.urls import v1_api

from post.api import PostResource


v1_api.register(PostResource())

# xxx: may need to include ckeditor urls here. check!

urlpatterns = patterns(
    '',
    url(
        r'^(?P<category_slug>[\w-]+)/(?P<slug>[\w-]+)/$',
        'jmbo.views.object_detail',
        name='post_categorized_object_detail'
    ),
    url(
        r'^(?P<slug>[\w-]+)/$',
        'jmbo.views.object_detail',
        name='post_object_detail'
    ),
)



from bs4 import BeautifulSoup

from django.core.urlresolvers import reverse
from ckeditor.fields import RichTextField

from jmbo.models import ModelBase


class Post(ModelBase):
    autosave_fields = ('content',)

    content = RichTextField(
        blank=True,
        null=True,
    )

    class Meta:
        verbose_name = 'Post'
        verbose_name_plural = 'Posts'

    @property
    def content_pages(self):
        marker = '--m-a-r-k-er--'
        soup = BeautifulSoup(self.content)
        elems = soup.find_all('div', attrs={'style': 'page-break-after: always;'})
        for elem in elems:
            elem.replace_with(marker)
        return soup.renderContents().split(marker)
